==> vtiger-4.0p1_1.tbz: www/vtiger/modules/System/includes/lang/sk.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: sk.php,v 1.1 2005/03/14 07:42:10 shankarr Exp $

$charset                = 'iso-8859-2';

$text['title']          = 'Informcie o systme';

$text['vitals']         = 'Zkladn informcie';
$text['hostname']       = 'Meno potaa';
$text['ip']             = 'IP adresa';
$text['kversion']       = 'Verzia jadra';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Prihlsench uvateov';
$text['loadavg']        = 'Priemer loadu';

$text['hardware']       = 'Hardwarov informcie';
$text['numcpu']         = 'Procesory';
$text['cpumodel']       = 'Model';
$text['mhz']            = 'Frekvencia';
$text['cache']          = 'Vekos cache';
$text['bogomips']       = 'Bogomipsov';
$text['pci']            = 'PCI zariadenia';
$text['ide']            = 'IDE zariadenia';
$text['scsi']           = 'SCSI zariadenia';

$text['netusage']       = 'Pouvanie siete';
$text['device']         = 'Zariadenia';
$text['received']       = 'Prijatch';
$text['sent']           = 'Odoslanch';
$text['errors']         = 'Chyby/Vypustench';

$text['memusage']       = 'Obsadenie pamti';
$text['phymem']         = 'Fyzick pam';
$text['swap']           = 'Swap';

$text['fs']             = 'Namountovan sborov systmy';
$text['mount']          = 'Adresr';
$text['partition']      = 'Partcia';

$text['percent']        = 'Obsadench';
$text['type']           = 'Typ';
$text['free']           = 'Vonch';
$text['used']           = 'Pouitch';
$text['size']           = 'Vekos';
$text['totals']         = 'Celkom';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'iadne';

$text['capacity']       = 'Kapacita';

$text['template']       = 'ablna';
$text['language']       = 'Jazyk';
$text['submit']         = 'Odosla';
$text['created']        = 'Vytvoren pomocou';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'dn';
$text['hours']          = 'hodn';
$text['minutes']        = 'mint';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>

==> vtiger-4.2.4.tbz: www/vtiger/modules/System/includes/lang/sk.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: sk.php,v 1.10 2004/08/30 15:51:26 webbie Exp $

$charset                = 'iso-8859-2';

$text['title']          = 'Informcie o systme';

$text['vitals']         = 'Zkladn informcie';
$text['hostname']       = 'Meno potaa';
$text['ip']             = 'IP adresa';
$text['kversion']       = 'Verzia jadra';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Prihlsench uvateov';
$text['loadavg']        = 'Priemer loadu';

$text['hardware']       = 'Hardwarov informcie';
$text['numcpu']         = 'Procesory';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'Frekvencia';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Vekos cache';
$text['bogomips']       = 'Bogomipsov';

$text['pci']            = 'PCI zariadenia';
$text['ide']            = 'IDE zariadenia';
$text['scsi']           = 'SCSI zariadenia';
$text['usb']            = 'USB zariadenia';

$text['netusage']       = 'Pouvanie siete';
$text['device']         = 'Zariadenia';
$text['received']       = 'Prijatch';
$text['sent']           = 'Odoslanch';
$text['errors']         = 'Chyby/Vypustench';

$text['memusage']       = 'Obsadenie pamti';
$text['phymem']         = 'Fyzick pam';
$text['swap']           = 'Swap';

$text['fs']             = 'Namountovan sborov systmy';
$text['mount']          = 'Adresr';
$text['partition']      = 'Partcia';

$text['percent']        = 'Obsadench';
$text['type']           = 'Typ';
$text['free']           = 'Vonch';
$text['used']           = 'Pouitch';
$text['size']           = 'Vekos';
$text['totals']         = 'Celkom';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'iadne';

$text['capacity']       = 'Kapacita';

$text['template']       = 'ablna';
$text['language']       = 'Jazyk';
$text['submit']         = 'Odosla';
$text['created']        = 'Vytvoren pomocou';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'dn';
$text['hours']          = 'hodn';
$text['minutes']        = 'mint';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>
